==> qmmp_0.8.2.orig.tar.bz2: qmmp-0.8.2/src/plugins/Input/mad/translations/mad_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>DecoderMADFactory</name>
    <message>
        <location filename="../decodermadfactory.cpp" line="104"/>
        <source>MPEG Plugin</source>
        <translation>MPEG 插件</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="107"/>
        <source>MPEG Files</source>
        <translation>MPEG 文件</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="246"/>
        <source>About MPEG Audio Plugin</source>
        <translation>关于 MPEG 音频插件</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="247"/>
        <source>Qmmp MPEG Audio Plugin</source>
        <translation>Qmmp MPEG 音频插件</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="248"/>
        <source>Compiled against libmad version:</source>
        <translation>编译基于 libmad 版本：</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="252"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="253"/>
        <source>Source code based on mq3 and madplay projects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MPEGMetaDataModel</name>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="70"/>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <source>Bitrate</source>
        <translation>比特率</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Sample rate</source>
        <translation>取样率</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="78"/>
        <location filename="../mpegmetadatamodel.cpp" line="81"/>
        <location filename="../mpegmetadatamodel.cpp" line="84"/>
        <location filename="../mpegmetadatamodel.cpp" line="87"/>
        <source>Mode</source>
        <translation>风格</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="90"/>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="91"/>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="93"/>
        <location filename="../mpegmetadatamodel.cpp" line="95"/>
        <source>Protection</source>
        <translation>保护</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="93"/>
        <location filename="../mpegmetadatamodel.cpp" line="97"/>
        <location filename="../mpegmetadatamodel.cpp" line="101"/>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="95"/>
        <location filename="../mpegmetadatamodel.cpp" line="99"/>
        <location filename="../mpegmetadatamodel.cpp" line="103"/>
        <source>No</source>
        <translation>否</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="97"/>
        <location filename="../mpegmetadatamodel.cpp" line="99"/>
        <source>Copyright</source>
        <translation>版权</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="101"/>
        <location filename="../mpegmetadatamodel.cpp" line="103"/>
        <source>Original</source>
        <translation>原创</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <location filename="../settingsdialog.ui" line="110"/>
        <location filename="../settingsdialog.ui" line="159"/>
        <source>ID3v1</source>
        <translation>ID3v1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="66"/>
        <location filename="../settingsdialog.ui" line="115"/>
        <location filename="../settingsdialog.ui" line="164"/>
        <source>ID3v2</source>
        <translation>ID3v2</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="210"/>
        <source>ID3v1 encoding:</source>
        <translation>ID3v1 编码：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="236"/>
        <source>ID3v2 encoding:</source>
        <translation>ID3v2 编码：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPEG Plugin Settings</source>
        <translation>MPEG 插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Tag Priority</source>
        <translation>标签优先</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>First:</source>
        <translation>第一：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <location filename="../settingsdialog.ui" line="120"/>
        <location filename="../settingsdialog.ui" line="169"/>
        <source>APE</source>
        <translation>APE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <location filename="../settingsdialog.ui" line="125"/>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Disabled</source>
        <translation>无效</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>Second:</source>
        <translation>第二：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>Third:</source>
        <translation>第三：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="198"/>
        <source>Encodings</source>
        <translation>编码</translation>
    </message>
</context>
</TS>

==> qmmp-0.10.10.tar.bz2: qmmp-0.10.10/src/plugins/Input/mad/translations/mad_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>DecoderMADFactory</name>
    <message>
        <location filename="../decodermadfactory.cpp" line="113"/>
        <source>MPEG Plugin</source>
        <translation>MPEG 插件</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="116"/>
        <source>MPEG Files</source>
        <translation>MPEG 文件</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="272"/>
        <source>About MPEG Audio Plugin</source>
        <translation>关于 MPEG 音频插件</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="273"/>
        <source>Qmmp MPEG Audio Plugin</source>
        <translation>Qmmp MPEG 音频插件</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="274"/>
        <source>Compiled against libmad version:</source>
        <translation>编译基于 libmad 版本：</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="278"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermadfactory.cpp" line="279"/>
        <source>Source code based on mq3 and madplay projects</source>
        <translation>源代码基于mq3及madplay项目</translation>
    </message>
</context>
<context>
    <name>MPEGMetaDataModel</name>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="70"/>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <source>Bitrate</source>
        <translation>比特率</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <source>kbps</source>
        <translation>千比特每秒</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Sample rate</source>
        <translation>取样率</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Hz</source>
        <translation>赫兹</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="78"/>
        <location filename="../mpegmetadatamodel.cpp" line="81"/>
        <location filename="../mpegmetadatamodel.cpp" line="84"/>
        <location filename="../mpegmetadatamodel.cpp" line="87"/>
        <source>Mode</source>
        <translation>风格</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="90"/>
        <source>KB</source>
        <translation>千字节</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="91"/>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="93"/>
        <location filename="../mpegmetadatamodel.cpp" line="95"/>
        <source>Protection</source>
        <translation>保护</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="93"/>
        <location filename="../mpegmetadatamodel.cpp" line="97"/>
        <location filename="../mpegmetadatamodel.cpp" line="101"/>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="95"/>
        <location filename="../mpegmetadatamodel.cpp" line="99"/>
        <location filename="../mpegmetadatamodel.cpp" line="103"/>
        <source>No</source>
        <translation>否</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="97"/>
        <location filename="../mpegmetadatamodel.cpp" line="99"/>
        <source>Copyright</source>
        <translation>版权</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="101"/>
        <location filename="../mpegmetadatamodel.cpp" line="103"/>
        <source>Original</source>
        <translation>原创</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPEG Plugin Settings</source>
        <translation>MPEG 插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Tag Priority</source>
        <translation>标签优先</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>First:</source>
        <translation>第一：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <location filename="../settingsdialog.ui" line="110"/>
        <location filename="../settingsdialog.ui" line="159"/>
        <source>ID3v1</source>
        <translation>ID3v1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="66"/>
        <location filename="../settingsdialog.ui" line="115"/>
        <location filename="../settingsdialog.ui" line="164"/>
        <source>ID3v2</source>
        <translation>ID3v2</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <location filename="../settingsdialog.ui" line="120"/>
        <location filename="../settingsdialog.ui" line="169"/>
        <source>APE</source>
        <translation>APE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <location filename="../settingsdialog.ui" line="125"/>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Disabled</source>
        <translation>无效</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>Second:</source>
        <translation>第二：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>Third:</source>
        <translation>第三：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="198"/>
        <source>Encodings</source>
        <translation>编码</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="210"/>
        <source>ID3v1 encoding:</source>
        <translation>ID3v1 编码：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="236"/>
        <source>ID3v2 encoding:</source>
        <translation>ID3v2 编码：</translation>
    </message>
</context>
</TS>
